@@ -32,9 +32,9 @@ sub to_SQL
 
     my( $sql, $values ) = $self->inner->to_SQL( $options );
     if( wantarray ) {
-        return ( "(NOT $sql)", $values );
+        return ( "NOT ($sql)", $values );
     } else {
-        return "(NOT $sql)";
+        return "NOT ($sql)";
     }
 }
 
